@@ -43,6 +43,7 @@
 
 #include "private.h"
 #include <ccrtp/cqueue.h>
+#include <cstdlib>
 
 #ifdef  CCXX_NAMESPACES
 namespace ost {
@@ -798,10 +799,10 @@ QueueRTCPManager::dispatchBYE(const std::string& reason)
 		if ( padlen ) {
 			memset(buffer + len,0,padlen);
 			len += padlen;
+                        pkt->info.BYE.length += padlen;
 		}
 	}
 	pkt->fh.length = htons(((len - len1) >> 2) - 1);
-	pkt->fh.padding = (padlen > 0);
 
 	return sendControlToDestinations(buffer,len);
 }
@@ -885,7 +886,7 @@ QueueRTCPManager::dispatchControlPacket(void)
 		pkt->info.SR.sinfo.NTPMSW = htonl(now.tv_sec + NTP_EPOCH_OFFSET);
 		pkt->info.SR.sinfo.NTPLSW = htonl((uint32)(((double)(now.tv_usec)*(uint32)(~0))/1000000.0));
 		// RTP timestamp
-		uint32 tstamp = now.tv_usec - getInitialTime().tv_usec;
+		int32 tstamp = now.tv_usec - getInitialTime().tv_usec;
 		tstamp *= (getCurrentRTPClockRate()/1000);
 		tstamp /= 1000;
 		tstamp += (now.tv_sec - getInitialTime().tv_sec) *
